==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/ArrayCore/src/HRFKDirectRayleigh.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-03-29
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HRFKDIRECTRAYLEIGH_H
#define HRFKDIRECTRAYLEIGH_H

#include "HRFKDirectRadial.h"
#include "FKSteeringThreeComponentRayleighRadial.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT HRFKDirectRayleigh : public HRFKDirectRadial
  {
  public:
    HRFKDirectRayleigh(FKCache * cache);
    ~HRFKDirectRayleigh();

    virtual void addCrossSpectrum();

    //virtual void setGrid(FKGradientSearch * g, double cacheStep, double step, double size);
    virtual void setGrid(FKGridSearch * g, double step, double size);
    virtual bool initGrid(int n);
    virtual void initGrid(const Point& kell, int index);

    virtual const FKSteering * steering(int index) const {return &FKSteeringThreeComponentRayleighRadial::cache(_gridCache, index);}

    virtual double value(const Point& kell, int index) const;
    virtual double value(const Point& kell) const;

    //virtual void setGradient(FKPower& p) const;
    //virtual void setHessian(FKPower& p) const;

    //virtual void setGradient(const Point& kell, FKPower& p) const;
    //virtual void setHessian(const Point& kell, FKPower& p) const;

    virtual bool hasEllipticity() const {return true;}
    virtual double ellipticity(const Point& kell);
    virtual double noise(const Point&) const;
    virtual double power(double optimumPower) const;

    virtual double thirdMinimum() const {return -0.5*M_PI;}
    virtual double thirdMaximum() const {return 0.5*M_PI;}
    virtual double thirdStep() const {return M_PI/20;}
  protected:
    double ellipticityHelper(double ellh, double ellz);

    double _RoverN;
    double _ellipticity;

    mutable qint64 _countGrid, _countFree;
  };

} // namespace ArrayCore

#endif // HRFKDIRECTRAYLEIGH_H

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/HRFKDirectRayleigh.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-03-29
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HRFKDIRECTRAYLEIGH_H
#define HRFKDIRECTRAYLEIGH_H

#include "HRFKDirectRadial.h"
#include "FKSteeringThreeComponentRayleighRadial.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT HRFKDirectRayleigh : public HRFKDirectRadial
  {
  public:
    HRFKDirectRayleigh(FKCache * cache);
    ~HRFKDirectRayleigh();

    virtual void addCrossSpectrum();

    //virtual void setGrid(FKGradientSearch * g, double cacheStep, double step, double size);
    virtual void setGrid(FKGridSearch * g, double step, double size);
    virtual bool initGrid(int n);
    virtual void initGrid(const Point& kell, int index);

    virtual const FKSteering * steering(int index) const {return &FKSteeringThreeComponentRayleighRadial::cache(_gridCache, index);}

    virtual double value(const Point& kell, int index) const;
    virtual double value(const Point& kell) const;

    //virtual void setGradient(FKPower& p) const;
    //virtual void setHessian(FKPower& p) const;

    //virtual void setGradient(const Point& kell, FKPower& p) const;
    //virtual void setHessian(const Point& kell, FKPower& p) const;

    virtual bool hasEllipticity() const {return true;}
    virtual double ellipticity(const Point& kell, bool& ok);
    virtual double noise(const Point&) const;
    virtual double power(double optimumPower) const;

    virtual double thirdMinimum() const {return -0.5*M_PI;}
    virtual double thirdMaximum() const {return 0.5*M_PI;}
    virtual double thirdStep() const {return M_PI/20;}
  protected:
    double ellipticityHelper(double ellh, double ellz, bool& ok);

    double _RoverN;
    double _ellipticity;

    mutable qint64 _countGrid, _countFree;
  };

} // namespace ArrayCore

#endif // HRFKDIRECTRAYLEIGH_H
